function [eigf_res, nreigf] = rotade3D_eigenmodes(nrefD, SCALE, l, lb, w, t)

flreport('off');
if (exist('fem0','var')), clear fem0 ; end;
if (exist('fem1','var')), clear fem1 ; end;
if (exist('fem2','var')), clear fem2 ; end;
if (exist('fem','var')),  clear fem ; end;

found = 0;

% COMSOL version
clear vrsn
vrsn.name = 'COMSOL 3.5';
vrsn.ext = 'a';
vrsn.major = 0;
vrsn.build = 603;
vrsn.rcs = '$Name:  $';
vrsn.date = '$Date: 2008/12/03 17:02:19 $';
fem.version = vrsn;

% Constants
fem.const = { 'l',l,...
  'radius','0.5', ...
  'lb',lb,...
  'lt','l+radius+lb', ...
  'width',w, ...
  'gap','1', ...
  'thickness',t, ...
  'rho_quartz','2650', ...
  'c11','86.80e9', ...
  'c12','7.04e9', ...
  'c13','11.91e9', ...
  'c14','-18.04e9', ...
  'c33','105.75e9', ...
  'c44','58.20e9', ...
  'c66','39.88e9', ...
  'alpha1','13*(10^-6)', ...
  'alpha2','alpha1', ...
  'alpha3','8*(10^-6)',...
  'SCALE', SCALE};

% % Geometry
g1=block3('2*width+gap','thickness','lt','base','center','pos',{'0','0','l-lt/2'},'axis',{'0','0','1'},'rot','0','const',fem.const);
g2=block3('gap','thickness','l','base','center','pos',{'0','0','l/2'},'axis',{'0','0','1'},'rot','0','const',fem.const);
g3=cylinder3('0.5','thickness','pos',{'0','-thickness/2','0'},'axis',{'0','1','0'},'rot','0','const',fem.const);
g4=geomcomp({g2,g3},'ns',{'BLK2','CYL1'},'sf','BLK2+CYL1','face','all','edge','all');
g5=geomcomp({g1,g4},'ns',{'BLK1','CO1'},'sf','BLK1-CO1','face','all','edge','all');

clear s
s.objs={g5};
s.name={'CO2'};
s.tags={'g5'};

fem.draw=struct('s',s);
fem.geom=geomcsg(fem);

% Initialize mesh
fem.mesh=meshinit(fem, ...
                  'hauto',4);

% Refine mesh
for nr = 1:nrefD
fem.mesh=meshrefine(fem, ...
                    'mcase',0, ...
                    'rmethod','longest');
end

% Application mode 1
clear appl
appl.mode.class = 'FlSolid3';
appl.dim = {'u4','v4','w4'};
appl.gporder = 4;
appl.cporder = 2;
appl.assignsuffix = '_sld';
clear prop
prop.analysis='eigen';
appl.prop = prop;
clear bnd
bnd.Hy = {0,1};
bnd.Hx = {0,1};
bnd.Hz = {0,1};
bnd.ind = [1,1,2,1,1,1,1,1,1,1,1];
appl.bnd = bnd;
fem.appl{1} = appl;
fem.frame = {'ref'};

% Shape functions
fem.shape = {'shlag(2,''u4'')','shlag(2,''v4'')','shlag(2,''w4'')'};
fem.border = 1;
clear units;
units.basesystem = 'SI';
fem.units = units;

% Subdomain settings
clear equ
equ.weak = '-ex_sld_test*sx_sld-ey_sld_test*sy_sld-ez_sld_test*sz_sld-2*exy_sld_test*sxy_sld-2*eyz_sld_test*syz_sld-2*exz_sld_test*sxz_sld-(SCALE^2)*jomega_sld^2*rho_quartz*(u4_test*u4+v4_test*v4+w4_test*w4)';
equ.ind = [1];
equ.dim = {'u4','v4','w4'};
equ.var = {
  'sx_sld', 'c11*(ex_sld)+c12*(ey_sld)+c13*(ez_sld)+2*c14*eyz_sld', ...
  'sy_sld', 'c12*(ex_sld)+c11*(ey_sld)+c13*(ez_sld)-2*c14*eyz_sld', ...
  'sz_sld', 'c13*(ex_sld)+c13*(ey_sld)+c33*(ez_sld)', ...
  'syz_sld','c14*(ex_sld)-c14*(ey_sld)+2*c44*eyz_sld', ...
  'sxz_sld','2*(c44*exz_sld +c14*exy_sld)', ...
  'sxy_sld','2*(c14*exz_sld +c66*exy_sld)', ...
  'ex_sld','u4x', ...
  'ey_sld','v4y', ...
  'ez_sld','w4z', ...
  'exy_sld','0.5*(u4y+v4x)', ...
  'eyz_sld','0.5*(v4z+w4y)', ...
  'exz_sld','0.5*(u4z+w4x)'};
fem.equ = equ;

% ODE Settings
clear ode
clear units;
units.basesystem = 'SI';
ode.units = units;
fem.ode=ode;

% Multiphysics
fem=multiphysics(fem, ...
  'sdl',[]);

% Extend mesh
fem.xmesh=meshextend(fem);

% Solve problem
fem.sol=femeig(fem, ...
               'solcomp',{'w4','v4','u4'}, ...
               'outcomp',{'w4','v4','u4'}, ...
               'rowscale','off', ...
               'blocksize','auto', ...
               'neigs',6, ...
               'linsolver','spooles');
%Print the computed values:
fidselect_emode = fopen('select_emode_EVP.txt', 'a+');
if (fidselect_emode == -1)
  error('error opening log file');
end;
eigf   = 0;
nreigf = 0;
while (found ~=1)
    
nreigf = nreigf +1;    
% Integrate
u_L = postint(fem,'(u4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',6, ...
           'edim',0, ...
           'solnum',nreigf);
u_R = postint(fem,'(u4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',12, ...
           'edim',0, ...
           'solnum',nreigf);
       
v_L = postint(fem,'(v4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',6, ...
           'edim',0, ...
           'solnum',nreigf);
v_R = postint(fem,'(v4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',12, ...
           'edim',0, ...
           'solnum',nreigf);
w_L = postint(fem,'(w4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',6, ...
           'edim',0, ...
           'solnum',nreigf);
w_R = postint(fem,'(w4)', ...
           'unit','m', ...
           'recover','off', ...
           'dl',12, ...
           'edim',0, ...
           'solnum',nreigf);
fprintf(fidselect_emode, '%2d %7.4f %8.2f %6.3f %6.3f %11.2e %6.3f %6.3f %11.2e %11.2e %6.3f %6.3f %11.2e\n', ...
          nreigf, SCALE, i*fem.sol.lambda(nreigf)/(2*pi),u_L, u_R,abs(u_L+u_R), v_L, v_R, ...
          abs(abs(u_L)/abs(v_L)), abs(abs(u_R)/abs(v_R)), w_L, w_R , abs(abs(u_L)/abs(w_L)));      

if ( abs(u_L+u_R) < 1e-1 && ...
   ((abs(abs(u_L)/abs(v_L))> 2) || abs(abs(u_R)/abs(v_R))> 2) && ...
   ((abs(abs(u_L)/abs(w_L))> 2) || abs(abs(u_R)/abs(w_R))> 2) )
    found = 1;
    eigf   = i*fem.sol.lambda(nreigf)/(2*pi);
    fem.xmesh    = meshextend (fem);
    N_e   = size(fem.mesh.t,2); % number of mesh elements
    N_p   = size(fem.mesh.p,2); % number of points, i.e., vertices
    ndofs = xmeshinfo(fem, 'out','ndofs'); % DOFs directly, as documented
    fprintf(fidselect_emode, 'Found antysymmetric mode!!! dof = %7d f = %8.2f\n', ndofs, i*fem.sol.lambda(nreigf)/(2*pi));

%    %Print the computed values:
%    fid1 = fopen('statistics_eigf.txt', 'a+');
%    if (fid1 == -1)
%      error('error opening log file');
%    end;
%    %fprintf(fid1, ' r     N_e     N_p       D        f  \n');
%    fprintf(fid1, '%2d %7d %7d %7d %8.2f \n', ...
%              nrefD, N_e, N_p, ndofs, eigf);
%    fclose(fid1); 
end
end %while

if (eigf == 0)
%     % Print the computed values:
%     fid2 = fopen('statistics_eigf.txt', 'a+');
%     if (fid2 == -1)
%       error('error opening log file');
%     end;
%     %fprintf(fid, ' r       N       D        f      max(|u|)    max(|v|)     max(|w|)   time \n');
% %     fprintf(fid2, '%2d %7d %7d %7d %8.2f %12.4e %12.4e %12.4e %s \n', ...
% %               0, N_e, N_p, ndofs, eigf,  absmaxu, absmaxv, absmaxw, 'SCALED equation - EVP deform');
%     fprintf(fid2,'Warning:: resonance frequency NOT found! for SCALE = %d, l = %7.5f, w = %7.5f, t = %7.5f\n', SCALE, l, w, t);
%     fclose(fid2);
end
fprintf(fidselect_emode, '%s\n', '----------------------------------------------------');
fclose(fidselect_emode);

eigf_res    = eigf;
if (eigf_res == 0)
	fprintf('Warning:: resonance frequency NOT found! for SCALE = %d, l = %7.5f, lb = %7.5f, w = %7.5f, t = %7.5f\n', SCALE, l, lb, w, t);
end

%flsave('fem_eigf', fem);
end