% COMSOL Multiphysics Model M-file
% Generated by COMSOL 3.5a (COMSOL 3.5.0.603, $Date: 2008/12/03 17:02:19 $)
function [Pd, Pi] = rotade_matlab(xs, ys, zs, nrefT1, nrefT2, omega)

if (exist('fem0','var')), clear fem0 ; end;
if (exist('fem1','var')), clear fem1 ; end;
if (exist('fem2','var')), clear fem2 ; end;
if (exist('fem','var')),  clear fem ; end;

% COMSOL version
clear vrsn
vrsn.name = 'COMSOL 3.5';
vrsn.ext = 'a';
vrsn.major = 0;
vrsn.build = 603;
vrsn.rcs = '$Name:  $';
vrsn.date = '$Date: 2008/12/03 17:02:19 $';
fem.version = vrsn;

% Geometry
% Import CAD data
garr = geomimport('..\CADfiles\geometry.mphbin', ...
                  'repairtol','1.0E-5', ...
                  'sdim',3);
[g1]=deal(garr{:});

% Constants
fem.const = {'omega','2*pi*32785.47', ...
  'xs',xs, ...
  'ys',ys, ...
  'zs',zs, ...
  'rho_quartz','2650', ...
  'cp_quartz','733', ...
  'rho_CO2','0.047850', ...
  'cp_CO2','0.84081e3', ...
  'K_CO2','0.016346', ...
  'c_CO2','K_CO2/(rho_CO2*cp_CO2)', ...
  'K1_q','6.5', ...
  'K2_q','6.5', ...
  'K3_q','11.3', ...
  'c1_q','K1_q/(rho_quartz*cp_quartz)', ...
  'c2_q','K2_q/(rho_quartz*cp_quartz)', ...
  'c3_q','K3_q/(rho_quartz*cp_quartz)', ...
  'w0','7.5e-6', ...
  'lam','1.55e-6', ...                        
  'W_L', '30e-3'};                     %NEW! added per Dr. K's email!!!};

% Global expressions
fem.globalexpr = {'yR','pi*w0^2/lam', ...
  'wy','w0*sqrt(1+(y/yR)^2)', ...
  'A_CO2p','(1/(rho_CO2*cp_CO2))*(2*W_L/pi)', ...        %!!! this does not inlcude the abs coeff
  'A_qzp', '(1/(rho_quartz*cp_quartz))*(2*W_L/pi)', ...  %!!! this does not inlcude the abs coeff
  'source_CO2','(A_CO2p/wy^2)*exp(-2*((x-xs)^2+(z-zs)^2)/wy^2)', ...
  'source_qz', '(A_qzp/wy^2)*exp(-2*((x-xs)^2+(z-zs)^2)/wy^2)', ...
  'I','2*W_L/(pi*wy^2)*exp(-2*((x-xs)^2+(z-zs)^2)/wy^2)'};

% Geometry

% Analyzed geometry
clear s
s.objs={g1};
s.name={'CO1'};
s.tags={'g1'};

fem.draw=struct('s',s);
fem.geom=geomcsg(fem);

% Initialize mesh
fem.mesh=meshinit(fem, ...
                  'hauto',5);

% (Default values are not included)

% Application mode 1
clear appl
appl.mode.class = 'Helmholtz';
appl.sshape = 2;
appl.assignsuffix = '_hzeq';
clear bnd
bnd.r = {0,0,'boundaryT(x-xs,z-zs)'};
bnd.type = {'dir','neu','dir'};
bnd.ind = [1,3,1,1,3,2,2,2,2,2,2,2,2,2,2,2,1];
appl.bnd = bnd;
clear equ
equ.f = {'source_CO2','source_qz'};
equ.c = {'c_CO2',{{'c1_q';'c2_q';'c3_q'}}};
equ.a = 'i*omega';
equ.ind = [1,2];
appl.equ = equ;
fem.appl{1} = appl;
fem.frame = {'ref'};
fem.border = 1;
clear units;
units.basesystem = 'SI';
fem.units = units;

% Descriptions
clear descr
descr.const= {'c33','N/m^2','E','Youngs modulus [Pa]','c2_q','m^2/s','c44','N/m^2','K3_q','J/(m s K)','c66','N/m^2','mu','Poisson ratio','K_CO2','thermal conduction (W/(mK))','rho_quartz','density of quartz [kg/m^3]','omega','angular frequency [1/s]','c_CO2','diffusion coefficient [m^2/s]','c3_q','m^2/s','cp_quartz','specific heat for quartz  J/(kgK)','sigma','beam width [m]','c1_q','m^2/s','rho_CO2','density of air [kg/m^3]','cp_CO2','specific heat for air  J/(kgK)','K2_q','J/(m s K)','c11','N/m^2','c13','N/m^2','c12','N/m^2','K1_q','J/(m s K)','c14','N/m^2'};
fem.descr = descr;

% ODE Settings
clear ode
clear units;
units.basesystem = 'SI';
ode.units = units;
fem.ode=ode;

% Multiphysics
fem=multiphysics(fem);

% Extend mesh
fem.xmesh=meshextend(fem);

% Solve problem
tic;
fem=adaption(fem, ...
             'solcomp',{'u'}, ...
             'outcomp',{'u'}, ...
             'blocksize','auto', ...
             'solver','stationary', ...
             'eigselect',1, ...
             'maxt',10000000, ...
             'ngen',nrefT1, ...
             'rmethod','longest', ...
             'resorder','auto', ...
             'eefun','l2', ...
             'l2scale',1, ...
             'l2staborder',2, ...
             'tppar',1.1, ...
	         'linsolver','gmres', ...
             'itol',1.0E-8, ...
             'prefun','ssor', ...
             'geomnum',1);
tsec = toc;


% obtain statistics about the mesh
filename = sprintf('statistics_T1.txt');
fid = fopen(filename, 'a+');
if (fid == -1)
  error('error opening log file');
end;
% obain mesh and FEM statistics:
N_e = size(fem.mesh.t,2); % number of mesh elements
N_p = size(fem.mesh.p,2); % number of points, i.e., vertices
ndofs = xmeshinfo(fem, 'out','ndofs'); % DOFs directly, as documented
fprintf(fid, '%8.5f %4d %7d %7d %7d %7.2f\n', ...
     zs, nrefT1, N_e, N_p, ndofs, tsec/60);
fclose(fid); 

%flsave T1 fem;

x = [0:0.15e-3/100:0.15e-3];
y = zeros(1, length(x));
z = zs*ones(1, length(x));
p = [x(:)';y(:)'; z(:)'];
T1 = postinterp(fem, 'abs(u)', p);
save dataT1 'x' 'T1'

% Store solution
fem1 = fem;

% Geometry
% Import CAD data
garr = geomimport('..\CADfiles\3DTF.mphbin', ...
                  'repairtol','1.0E-5', ...
                  'sdim',3);
[g2]=deal(garr{:});

% Analyzed geometry
clear s
s.objs={g2};
s.name={'CO1'};
s.tags={'g2'};

fem.draw=struct('s',s);
fem.geom=geomcsg(fem);

% Initialize mesh
fem.mesh=meshinit(fem, ...
                  'hauto',1);

% Refine mesh
% for it = 1:nrefT2
% fem.mesh=meshrefine(fem, ...
%                     'mcase',0, ...
%                     'rmethod','longest');
% end
% (Default values are not included)

% Application mode 1
clear appl
appl.mode.class = 'Helmholtz';
appl.assignsuffix = '_hzeq';
clear bnd
bnd.type = 'dir';
bnd.ind = [1,1,1,1,1,1,1,1,1,1,1];
appl.bnd = bnd;
fem.appl{1} = appl;

% Application mode 2
clear appl
appl.mode.class = 'Helmholtz';
appl.dim = {'u2'};
appl.name = 'hzeq2';
appl.sshape = 2;
appl.assignsuffix = '_hzeq2';
clear prop
clear weakconstr
weakconstr.value = 'off';
weakconstr.dim = {'lm2'};
prop.weakconstr = weakconstr;
appl.prop = prop;
clear bnd
bnd.r = {0,'u'};
bnd.type = 'dir';
bnd.ind = [1,2,1,2,2,2,2,2,2,2,1];
appl.bnd = bnd;
clear equ
equ.f = 0;
equ.c = {{{'c1_q';'c2_q';'c3_q'}}};
equ.a = 'i*omega';
equ.ind = [1];
appl.equ = equ;
fem.appl{2} = appl;
fem.frame = {'ref'};
fem.border = 1;
clear units;
units.basesystem = 'SI';
fem.units = units;

% Descriptions
clear descr
descr.const= {'c33','N/m^2','E','Youngs modulus [Pa]','c2_q','m^2/s','c44','N/m^2','K3_q','J/(m s K)','c66','N/m^2','mu','Poisson ratio','K_CO2','thermal conduction (W/(mK))','rho_quartz','density of quartz [kg/m^3]','omega','angular frequency [1/s]','c_CO2','diffusion coefficient [m^2/s]','c3_q','m^2/s','cp_quartz','specific heat for quartz  J/(kgK)','sigma','beam width [m]','c1_q','m^2/s','rho_CO2','density of air [kg/m^3]','cp_CO2','specific heat for air  J/(kgK)','K2_q','J/(m s K)','c11','N/m^2','c13','N/m^2','c12','N/m^2','K1_q','J/(m s K)','c14','N/m^2'};
fem.descr = descr;

% ODE Settings
clear ode
clear units;
units.basesystem = 'SI';
ode.units = units;
fem.ode=ode;

% Multiphysics
fem=multiphysics(fem);

% Extend mesh
fem.xmesh=meshextend(fem);
tic;
for it = 1:nrefT2
% Mapping stored solution to current extended mesh
u = asseminit(fem,'init',fem1.sol,'xmesh',fem1.xmesh,'blocksize','auto');

fem=adaption(fem, ...
             'u',u, ...
             'solcomp',{'u2'}, ...
             'outcomp',{'u','u2'}, ...
             'blocksize','auto', ...
             'solver','stationary', ...
             'eigselect',1, ...
             'maxt',10000000, ...
             'ngen',1, ...
             'rmethod','longest', ...
             'resorder','auto', ...
             'eefun','l2', ...
             'l2scale',1, ...
             'l2staborder',2, ...
             'tppar',1.1, ...
             'linsolver','gmres', ...
             'itol',1.0E-8, ...
             'maxlinit',100000, ...
             'prefun','ssor', ...
             'geomnum',1);
end

% Integrate

Pd =postint(fem,'I', ...
           'unit','1', ...
           'recover','off', ...
           'dl',2, ...
           'edim',2);    
       
E0 = postint(fem,'rho_quartz*cp_quartz*u2', ...
           'unit','m', ...
           'recover','off', ...
           'dl',1);
       
Pi = omega*abs(E0);

tsec = toc;
% obtain statistics about the mesh
filename = sprintf('statistics_T2.txt');
fid = fopen(filename, 'a+');
if (fid == -1)
  error('error opening log file');
end;
% obain mesh and FEM statistics:
N_e = size(fem.mesh.t,2); % number of mesh elements
N_p = size(fem.mesh.p,2); % number of points, i.e., vertices
ndofs = xmeshinfo(fem, 'out','ndofs'); % DOFs directly, as documented
fprintf(fid, '%8.5f %4d %7d %7d %7d %7.2f\n', ...
     zs, nrefT2, N_e, N_p, ndofs, tsec/60);
fclose(fid); 

%flsave T2 fem

x = [0.15e-3:(0.4e-3- 0.15e-3)/100:0.4e-3];
y = zeros(1, length(x));
z = zs*ones(1, length(x));
p = [x(:)';y(:)'; z(:)'];
T2 = postinterp(fem, 'abs(u2)', p);
save dataT2 'x' 'T2'

end